==> haskell-dns-4.2.0-36.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-dns-z-dns-internal
version:              4.2.0
package-name:         dns
lib-name:             dns-internal
id:                   dns-4.2.0-KoeNB718hJP9VMif6AiF4E-dns-internal
key:                  dns-4.2.0-KoeNB718hJP9VMif6AiF4E-dns-internal
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  929113219f3cc28ed8c0b25ba301e7be
exposed-modules:
    Network.DNS.Base32Hex Network.DNS.Decode.Internal
    Network.DNS.Decode.Parsers Network.DNS.Encode.Builders
    Network.DNS.Encode.Internal Network.DNS.Imports Network.DNS.Memo
    Network.DNS.Resolver.Internal Network.DNS.StateBinary
    Network.DNS.Types.Internal Network.DNS.Types.Resolver

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.2.0-KoeNB718hJP9VMif6AiF4E-dns-internal
depends:
    array-0.5.6.0 async-2.2.5-1Z88VuXAsSjFYCStMD3XFv
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm
    auto-update-0.1.6-9ryA5SLAC8xHZnIgVWhrWD base-4.18.2.1
    base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z containers-0.6.7
    crypton-1.0.4-79v9NTWfOZwB2brRt06GWH
    hourglass-0.2.12-9RVtelOw0wXG6YiBQxfho6
    iproute-1.7.15-8MQv32arzXu8ybbx4AUApr mtl-2.3.1
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    psqueues-0.2.8.2-7Hsdb7lcqdu8EEvCE8H06F

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dns
version:              4.2.0
visibility:           public
id:                   dns-4.2.0-HkcWBRCCYHxDWEoMNin6V7
key:                  dns-4.2.0-HkcWBRCCYHxDWEoMNin6V7
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  de5db4535039d948aa1a3c348011f685
exposed:              True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils

hidden-modules:       Network.DNS.Transport
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.2.0-HkcWBRCCYHxDWEoMNin6V7
depends:
    array-0.5.6.0 async-2.2.5-1Z88VuXAsSjFYCStMD3XFv
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm
    auto-update-0.1.6-9ryA5SLAC8xHZnIgVWhrWD base-4.18.2.1
    base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.4-79v9NTWfOZwB2brRt06GWH
    dns-4.2.0-KoeNB718hJP9VMif6AiF4E-dns-internal
    hourglass-0.2.12-9RVtelOw0wXG6YiBQxfho6
    iproute-1.7.15-8MQv32arzXu8ybbx4AUApr mtl-2.3.1
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    psqueues-0.2.8.2-7Hsdb7lcqdu8EEvCE8H06F

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-4.2.0-37-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-dns-z-dns-internal
version:              4.2.0
package-name:         dns
lib-name:             dns-internal
id:                   dns-4.2.0-DzZn1eH8NVmgvBjnDOlgv-dns-internal
key:                  dns-4.2.0-DzZn1eH8NVmgvBjnDOlgv-dns-internal
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  242933453b9cc2ee9811ecdd67a92874
exposed-modules:
    Network.DNS.Base32Hex Network.DNS.Decode.Internal
    Network.DNS.Decode.Parsers Network.DNS.Encode.Builders
    Network.DNS.Encode.Internal Network.DNS.Imports Network.DNS.Memo
    Network.DNS.Resolver.Internal Network.DNS.StateBinary
    Network.DNS.Types.Internal Network.DNS.Types.Resolver

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.2.0-DzZn1eH8NVmgvBjnDOlgv-dns-internal
depends:
    array-0.5.6.0 async-2.2.5-6z3frWRfGJJLLgOv3gEskc
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE
    auto-update-0.1.6-88T3ReDBoup7kx6uceSFG6 base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    containers-0.6.7 crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    hourglass-0.2.12-91uaLvWJDdFIwz6ObSsY6A
    iproute-1.7.15-G8PIBt0bMmIHonL1qb456T mtl-2.3.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    psqueues-0.2.8.2-8uu3DxPW2eP1IKqIpq0lUH

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dns
version:              4.2.0
visibility:           public
id:                   dns-4.2.0-JdNaF1PCYHDAdGPJzXW4wn
key:                  dns-4.2.0-JdNaF1PCYHDAdGPJzXW4wn
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  d61f89dee5400a8fd77c6aa8c5b6ba65
exposed:              True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils

hidden-modules:       Network.DNS.Transport
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.2.0-JdNaF1PCYHDAdGPJzXW4wn
depends:
    array-0.5.6.0 async-2.2.5-6z3frWRfGJJLLgOv3gEskc
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE
    auto-update-0.1.6-88T3ReDBoup7kx6uceSFG6 base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    dns-4.2.0-DzZn1eH8NVmgvBjnDOlgv-dns-internal
    hourglass-0.2.12-91uaLvWJDdFIwz6ObSsY6A
    iproute-1.7.15-G8PIBt0bMmIHonL1qb456T mtl-2.3.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    psqueues-0.2.8.2-8uu3DxPW2eP1IKqIpq0lUH

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
